@@ -23,38 +23,11 @@ import tempfile
 import unittest
 from io import StringIO
 
-from tests.common import build_temp_workspace, temp_workspace
+from tests.common import build_temp_workspace, RunContext, temp_workspace
 
 from yamllint import cli, config
 
 
-class RunContext:
-    """Context manager for ``cli.run()`` to capture exit code and streams."""
-
-    def __init__(self, case):
-        self.stdout = self.stderr = None
-        self._raises_ctx = case.assertRaises(SystemExit)
-
-    def __enter__(self):
-        self._raises_ctx.__enter__()
-        self.old_sys_stdout = sys.stdout
-        self.old_sys_stderr = sys.stderr
-        sys.stdout = self.outstream = StringIO()
-        sys.stderr = self.errstream = StringIO()
-        return self
-
-    def __exit__(self, *exc_info):
-        self.stdout = self.outstream.getvalue()
-        self.stderr = self.errstream.getvalue()
-        sys.stdout = self.old_sys_stdout
-        sys.stderr = self.old_sys_stderr
-        return self._raises_ctx.__exit__(*exc_info)
-
-    @property
-    def returncode(self):
-        return self._raises_ctx.exception.code
-
-
 # Check system's UTF-8 availability
 def utf8_available():
     try:
@@ -112,6 +85,9 @@ class CommandLineTestCase(unittest.TestCase):
                                                        'key: other value\n',
             # empty dir
             'empty-dir': [],
+            # symbolic link
+            'symlinks/file-without-yaml-extension': '42\n',
+            'symlinks/link.yaml': 'symlink://file-without-yaml-extension',
             # non-YAML file
             'no-yaml.json': '---\n'
                             'key: value\n',
@@ -152,6 +128,7 @@ class CommandLineTestCase(unittest.TestCase):
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
              os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
              os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'symlinks/link.yaml'),
              os.path.join(self.wd, 'warn.yaml')],
         )
 
@@ -189,6 +166,7 @@ class CommandLineTestCase(unittest.TestCase):
              os.path.join(self.wd, 'en.yaml'),
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
              os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'symlinks/link.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
 
@@ -226,6 +204,8 @@ class CommandLineTestCase(unittest.TestCase):
              os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
              os.path.join(self.wd, 'sub/directory.yaml/not-yaml.txt'),
              os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'symlinks/file-without-yaml-extension'),
+             os.path.join(self.wd, 'symlinks/link.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
 
@@ -247,6 +227,8 @@ class CommandLineTestCase(unittest.TestCase):
              os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
              os.path.join(self.wd, 'sub/directory.yaml/not-yaml.txt'),
              os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'symlinks/file-without-yaml-extension'),
+             os.path.join(self.wd, 'symlinks/link.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
 
@@ -711,6 +693,7 @@ class CommandLineTestCase(unittest.TestCase):
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
              os.path.join(self.wd, 'sub/directory.yaml/empty.yml'),
              os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'symlinks/link.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
 
@@ -727,9 +710,29 @@ class CommandLineTestCase(unittest.TestCase):
              os.path.join(self.wd, 's/s/s/s/s/s/s/s/s/s/s/s/s/s/s/file.yaml'),
              os.path.join(self.wd, 'sub/directory.yaml/not-yaml.txt'),
              os.path.join(self.wd, 'sub/ok.yaml'),
+             os.path.join(self.wd, 'symlinks/link.yaml'),
              os.path.join(self.wd, 'warn.yaml')]
         )
 
+        config = 'ignore: ["*.yaml", "*.yml", "!a.yaml"]'
+        with RunContext(self) as ctx:
+            cli.run(('--list-files', '-d', config, self.wd))
+        self.assertEqual(ctx.returncode, 0)
+        self.assertEqual(
+            sorted(ctx.stdout.splitlines()),
+            [os.path.join(self.wd, 'a.yaml')]
+        )
+        with RunContext(self) as ctx:
+            cli.run(('--list-files', '-d', config,
+                     os.path.join(self.wd, 'a.yaml'),
+                     os.path.join(self.wd, 'en.yaml'),
+                     os.path.join(self.wd, 'c.yaml')))
+        self.assertEqual(ctx.returncode, 0)
+        self.assertEqual(
+            sorted(ctx.stdout.splitlines()),
+            [os.path.join(self.wd, 'a.yaml')]
+        )
+
 
 class CommandLineConfigTestCase(unittest.TestCase):
     def test_config_file(self):
