@@ -32,6 +32,9 @@ used.
   even if ``required: only-when-needed`` is set.
 * ``allow-quoted-quotes`` allows (``true``) using disallowed quotes for strings
   with allowed quotes inside. Default ``false``.
+* ``check-keys`` defines whether to apply the rules to keys in mappings. By
+  default, ``quoted-strings`` rules apply only to values. Set this option to
+  ``true`` to apply the rules to keys as well.
 
 **Note**: Multi-line strings (with ``|`` or ``>``) will not be checked.
 
@@ -46,6 +49,7 @@ used.
      extra-required: []
      extra-allowed: []
      allow-quoted-quotes: false
+     check-keys: false
 
 .. rubric:: Examples
 
@@ -135,6 +139,18 @@ used.
 
     foo: 'bar"baz'
 
+#. With ``quoted-strings: {required: only-when-needed, check-keys: true,
+   extra-required: ["[:]"]}``
+
+   the following code snippet would **FAIL**:
+   ::
+
+    foo:bar: baz
+
+   the following code snippet would **PASS**:
+   ::
+
+    "foo:bar": baz
 """
 
 import re
@@ -149,12 +165,14 @@ CONF = {'quote-type': ('any', 'single', 'double'),
         'required': (True, False, 'only-when-needed'),
         'extra-required': [str],
         'extra-allowed': [str],
-        'allow-quoted-quotes': bool}
+        'allow-quoted-quotes': bool,
+        'check-keys': bool}
 DEFAULT = {'quote-type': 'any',
            'required': True,
            'extra-required': [],
            'extra-allowed': [],
-           'allow-quoted-quotes': False}
+           'allow-quoted-quotes': False,
+           'check-keys': False}
 
 
 def VALIDATE(conf):
@@ -176,7 +194,7 @@ yaml.resolver.Resolver.add_implicit_resolver(
                |[-+]?0[0-7_]+
                |[-+]?(?:0|[1-9][0-9_]*)
                |[-+]?0x[0-9a-fA-F_]+
-               |[-+]?[1-9][0-9_]*(?::[0-5]?[0-9])+)$''', re.X),
+               |[-+]?[1-9][0-9_]*(?::[0-5]?[0-9])+)$''', re.VERBOSE),
     list('-+0123456789'))
 
 
@@ -186,7 +204,11 @@ def _quote_match(quote_type, token_style):
             (quote_type == 'double' and token_style == '"'))
 
 
-def _quotes_are_needed(string):
+def _quotes_are_needed(string, is_inside_a_flow):
+    # Quotes needed on strings containing flow tokens
+    if is_inside_a_flow and set(string) & {',', '[', ']', '{', '}'}:
+        return True
+
     loader = yaml.BaseLoader('key: ' + string)
     # Remove the 5 first tokens corresponding to 'key: ' (StreamStartToken,
     # BlockMappingStartToken, KeyToken, ScalarToken(value=key), ValueToken)
@@ -194,12 +216,13 @@ def _quotes_are_needed(string):
         loader.get_token()
     try:
         a, b = loader.get_token(), loader.get_token()
+    except yaml.scanner.ScannerError:
+        return True
+    else:
         if (isinstance(a, yaml.ScalarToken) and a.style is None and
                 isinstance(b, yaml.BlockEndToken) and a.value == string):
             return False
         return True
-    except yaml.scanner.ScannerError:
-        return True
 
 
 def _has_quoted_quotes(token):
@@ -209,13 +232,27 @@ def _has_quoted_quotes(token):
 
 
 def check(conf, token, prev, next, nextnext, context):
+    if 'flow_nest_count' not in context:
+        context['flow_nest_count'] = 0
+
+    if isinstance(token, (yaml.FlowMappingStartToken,
+                          yaml.FlowSequenceStartToken)):
+        context['flow_nest_count'] += 1
+    elif isinstance(token, (yaml.FlowMappingEndToken,
+                            yaml.FlowSequenceEndToken)):
+        context['flow_nest_count'] -= 1
+
     if not (isinstance(token, yaml.tokens.ScalarToken) and
             isinstance(prev, (yaml.BlockEntryToken, yaml.FlowEntryToken,
                               yaml.FlowSequenceStartToken, yaml.TagToken,
-                              yaml.ValueToken))):
+                              yaml.ValueToken, yaml.KeyToken))):
 
         return
 
+    node = 'key' if isinstance(prev, yaml.KeyToken) else 'value'
+    if node == 'key' and not conf['check-keys']:
+        return
+
     # Ignore explicit types, e.g. !!str testtest or !!int 42
     if (prev and isinstance(prev, yaml.tokens.TagToken) and
             prev.value[0] == '!!'):
@@ -240,7 +277,7 @@ def check(conf, token, prev, next, nextnext, context):
         if (token.style is None or
             not (_quote_match(quote_type, token.style) or
                  (conf['allow-quoted-quotes'] and _has_quoted_quotes(token)))):
-            msg = "string value is not quoted with %s quotes" % quote_type
+            msg = f"string {node} is not quoted with {quote_type} quotes"
 
     elif conf['required'] is False:
 
@@ -249,38 +286,39 @@ def check(conf, token, prev, next, nextnext, context):
                 not _quote_match(quote_type, token.style) and
                 not (conf['allow-quoted-quotes'] and
                      _has_quoted_quotes(token))):
-            msg = "string value is not quoted with %s quotes" % quote_type
+            msg = f"string {node} is not quoted with {quote_type} quotes"
 
         elif not token.style:
             is_extra_required = any(re.search(r, token.value)
                                     for r in conf['extra-required'])
             if is_extra_required:
-                msg = "string value is not quoted"
+                msg = f"string {node} is not quoted"
 
     elif conf['required'] == 'only-when-needed':
 
         # Quotes are not strictly needed here
         if (token.style and tag == DEFAULT_SCALAR_TAG and token.value and
-                not _quotes_are_needed(token.value)):
+                not _quotes_are_needed(token.value,
+                                       context['flow_nest_count'] > 0)):
             is_extra_required = any(re.search(r, token.value)
                                     for r in conf['extra-required'])
             is_extra_allowed = any(re.search(r, token.value)
                                    for r in conf['extra-allowed'])
             if not (is_extra_required or is_extra_allowed):
-                msg = "string value is redundantly quoted with %s quotes" % (
-                    quote_type)
+                msg = f"string {node} is redundantly quoted with " \
+                      f"{quote_type} quotes"
 
         # But when used need to match config
         elif (token.style and
               not _quote_match(quote_type, token.style) and
               not (conf['allow-quoted-quotes'] and _has_quoted_quotes(token))):
-            msg = "string value is not quoted with %s quotes" % quote_type
+            msg = f"string {node} is not quoted with {quote_type} quotes"
 
         elif not token.style:
             is_extra_required = len(conf['extra-required']) and any(
                 re.search(r, token.value) for r in conf['extra-required'])
             if is_extra_required:
-                msg = "string value is not quoted"
+                msg = f"string {node} is not quoted"
 
     if msg is not None:
         yield LintProblem(
